
## tested under R version 3.6.1 (2019-07-05) -- "Action of the Toes"

library(xlsx)
library(lattice)
library(latticeExtra)

library(grid)
library(gridExtra)
library(ggplot2)
library(car)

setwd("H:/My_Documents/RVC_Staff_Support/John_Hutchinson/Scientific_Reports_DataCodes")

dmax <- read.xlsx("Kinematics Spreadsheet.xlsx", sheetName="Data3")
dmax <- subset(dmax,is.na(dmax$species..)==F)
dmax$clade.symm.asymm <- factor(paste(dmax$clade..,"-",dmax$symm.0..asymm.1))

running <- read.xlsx("Kinematics Spreadsheet.xlsx", sheetName = "Data2")

whole <- read.xlsx("Kinematics Spreadsheet.xlsx", sheetName = "Data1")
whole$clade.symm.asymm <- factor(paste(whole$clade..,"-",whole$symm.0..asymm.1))
table(whole$symm.0..asymm.1, whole$clade..)
table(whole$clade.symm.asymm)

whole$clade.symm.asymm <- recode(whole$clade.symm.asymm, "'1 - 0'='alli-symm'; 
                                 '2 - 0'='crocs-symm'; '2 - 1'='crocs-asymm'")

dmax$clade.symm.asymm <- recode(dmax$clade.symm.asymm, "'1 - 0'='alli-symm'; 
                                 '2 - 0'='crocs-symm'; '2 - 1'='crocs-asymm'")


######################################
######################################
### GRAPHS
######################################
######################################

##############################
### Figure 2 
### doube y-axis 
##############################
pgfun <- function(mark) function(n) grid.text(label = mark, gp = gpar(fontface=2),check.overlap = T,
                                            x = unit(0.03, "npc"), y = unit(0.97, "npc")) 
cexy <- 0.85
cexx <- 0.85
tickx <- 0.7
ticky <- 0.7
tck <- 0.5

cex_dot <- 0.7

## H2: two panel figures, left velocity and right F0.5 for y, body mass in x; 
## RSF on the left and DF on the right; running data same way

summary(subset(dmax, (symm.0..asymm.1==1 & clade..==2)))
        
rm(newy)
newx <- data.frame(body.mass..kg. = seq(1, 44,1))
newy <- data.frame(newy =exp(0.840102-0.063183*log(newx$body.mass..kg.)))

lattice.options(layout.heights=list(bottom.padding=list(x=1),
                                    top.padding=list(x=1)),
                layout.widths=list(right.padding=list(x=1),
                                   left.padding=list(x=1)))

f1 <- xyplot(velocity..m.s. ~ body.mass..kg., data=dmax,col="black",
             pch=1,lwd=1,ylim=c(1.3,4.2),cex=cex_dot,
             ylab=list(label=expression(paste(Velocity," (", u,")","(",ms^{-1},")"))), 
             ylab.right=list(label=expression(paste(Froude^{ 0.5}, "( ",widehat("u"), " )"))),
             xlab=list(label="Body mass (kg)"),  
             par.settings =simpleTheme(col = "black", lty =1:2, lwd=1,pch=c(1,4)),
       type=c("p"),scales=list(tck=c(tck,tck),y=list(log=T, at=c(1,1.5,2,3,4)),
                              x=list(log=T, at=c(1,2,5,10,20,30,40))),
       subset=(symm.0..asymm.1==1 & clade..==2))+
  xyplot(newy$newy ~ newx$body.mass..kg., col = "black", lty =1, lwd=1,
         type="a",scales =list(y=list(log=T),x=list(log=T)))

rm(newy)
newy <- data.frame(newy =exp(0.646258-0.186701*log(newx$body.mass..kg.)))
f2 <- xyplot(Froude.0.5 ~ body.mass..kg., data=dmax, col="black",pch=4,lwd=1,lty=2,ylim=c(0.7,3.5),

             xlab=list(cex=cexx, label="Body mass (kg)"), cex=cex_dot,
             type=c("p"),scales=list(tck=c(tck,tck),y=list(log=T, at=c(0.5,1,1.5,2,3)),
                                    x=list(log=T,at=c(1,2,5,10,20,30,40))),
       subset=(symm.0..asymm.1==1 & clade..==2))+
  xyplot(newy$newy ~ newx$body.mass..kg., col = "black", lty=2, lwd=1,
         type="a",scales=list(y=list(log=T),x=list(log=T)))


F2a <- update(doubleYScale(f1, f2, use.style = T,
                    auto.key=list(text=c("u", expression(widehat("u"))),lines=T, points=T,
                                  columns=2)),page = pgfun("(a)"),
              par.settings = list(layout.widths = list(left.padding = 1,
                                                       key.ylab.padding = 0,
                                                       ylab.axis.padding = 1,
                                                       axis.key.padding = -0.5,
                                                       right.padding = 1.5)))

rm(newy)
newy <- data.frame(newy =0.481923-0.014561*log(newx$body.mass..kg.))
f3 <- xyplot(rel.stride.freq  ~ body.mass..kg., data=dmax, col="black",pch=1,lty=1,ylim=c(0.17,0.63),
             ylab=list(label="Relative stride frequency (RSF)"), 
             ylab.right=list(label="Duty factor (DF)"), 
             xlab=list(label="Body mass (kg)"), cex=cex_dot,
             par.settings =simpleTheme(col = "black", lty =1:2, lwd=1,pch=c(1,4)),
             type=c("p"),scales=list(tck=c(tck,tck),x=list(log=T,at=c(1,2,5,10,20,30,40))),
             subset=(symm.0..asymm.1==1 & clade..==2))+
  xyplot(newy$newy ~ newx$body.mass..kg., col = "black", lty=1, lwd=1,
         type="a",scales=list(x=list(log=T)))

rm(newy)
newy <- data.frame(newy =0.267977+0.067621*log(newx$body.mass..kg.))
f4 <- xyplot(duty.factor ~ body.mass..kg., data=dmax,col="black",pch=4,lty=2,lwd=1,ylim=c(0.17,0.63),
             xlab=list(label="Body mass (kg)"),  cex=cex_dot,
             type=c("p"),scales=list(tck=c(tck,tck),
                                    x=list(log=T, at=c(1,2,5,10,20,30,40))),
             subset=(symm.0..asymm.1==1 & clade..==2))+
  xyplot(newy$newy ~ newx$body.mass..kg., col = "black", lty=2, lwd=1,
         ylab=list(cex=cexy, label="Duty factor (DF)"), 
         type="a",scales=list(x=list(log=T)))


F2b <- update(doubleYScale(f3, f4, use.style = T,
                           auto.key=list(text=c("RSF","DF"),lines=T, points=T,
                                         columns=2)),page = pgfun("(b)"),
              par.settings = list(layout.widths = list(left.padding = 1,
                                                       key.ylab.padding = 0,
                                                       ylab.axis.padding = 1,
                                                       axis.key.padding = -0.5,
                                                       right.padding = 1.5)))



###########################################################
###  H2: RUNNING DATA
###########################################################

rm(newy)
newx <- data.frame(body.mass..kg. = seq(0.5, 26,1))
newy <- data.frame(newy =exp(0.579532+0.012228*log(newx$body.mass..kg.)))

f1 <- xyplot(velocity..m.s. ~ body.mass..kg., data=running,col="black",pch=1,lwd=1,ylim=c(1.3,4.2),
             ylab=list(label=expression(paste(Velocity," (", u,")","(",ms^{-1},")"))), 
             ylab.right=list(label=expression(paste(Froude^{ 0.5}, "( ",widehat("u"), " )"))),
             xlab=list(label="Body mass (kg)"), cex=cex_dot, 
             par.settings = simpleTheme(col = "black", lty =1:2, lwd=1,pch=c(1,4)),
             type=c("p"),scales=list(y=list(log=T, at=c(1,1.5,2,3,4)),x=list(log=T, at=c(0.5,1,2,5,10,20,30,40))),
             subset=(symm.0..asymm.1==1 & clade..==2))+
  xyplot(newy$newy ~ newx$body.mass..kg., col = "black", lty =1, lwd=1,
         type="a",scales=list(y=list(log=T),x=list(log=T)))

rm(newy)
newy <- data.frame(newy =exp(0.368401-0.117613*log(newx$body.mass..kg.)))
f2 <- xyplot(Froude.0.5 ~ body.mass..kg., data=running, col="black",pch=4,lwd=1,lty=2,ylim=c(0.7,3.5),
             cex=cex_dot,
             type=c("p"),scales=list(y=list(log=T, at=c(0.5,1,1.5,2,3)),x=list(log=T,at=c(0.5,1,2,5,10,20,30,40))),
             subset=(symm.0..asymm.1==1 & clade..==2))+
  xyplot(newy$newy ~ newx$body.mass..kg., col = "black", lty=2, lwd=1,
         type="a",scales=list(y=list(log=T),x=list(log=T)))


F2c <- update(doubleYScale(f1, f2, use.style = T,
                           auto.key=list(text=c("u", expression(widehat("u"))),lines=T, points=T,
                                         columns=2)),page = pgfun("(c)"),
              par.settings = list(layout.widths = list(left.padding = 1,
                                                       key.ylab.padding = 0,
                                                       ylab.axis.padding = 1,
                                                       axis.key.padding = -0.5,
                                                       right.padding = 1.5)))

rm(newy)
newy <- data.frame(newy =0.486105-0.024215*log(newx$body.mass..kg.))
f3 <- xyplot(rel.stride.freq  ~ body.mass..kg., data=running, col="black",pch=1,lty=1,ylim=c(0.17,0.63),
             ylab=list(label="Relative stride frequency (RSF)"), 
             ylab.right=list(label="Duty factor (DF)"), 
             xlab="Body mass (kg)", cex=cex_dot,
             par.settings = simpleTheme(col = "black", lty =1:2, lwd=1,pch=c(1,4)),
             type=c("p"),scale=list(x=list(log=T,at=c(0.5,1,2,5,10,20,30,40))),
             subset=(symm.0..asymm.1==1 & clade..==2))+
  xyplot(newy$newy ~ newx$body.mass..kg., col = "black", lty=1, lwd=1,
         type="a",scale=list(x=list(log=T)))

rm(newy)
newy <- data.frame(newy =0.372488+0.021279*log(newx$body.mass..kg.))
f4 <- xyplot(duty.factor ~ body.mass..kg., data=running,col="black",pch=4,lty=2,lwd=1,ylim=c(0.17,0.63),
             ylab="Duty factor (DF)", xlab="Body mass (kg)", cex=cex_dot, 
             type=c("p"),scale=list(x=list(log=T, at=c(0.5,1,2,5,10,20,30,40))),
             subset=(symm.0..asymm.1==1 & clade..==2))+
  xyplot(newy$newy ~ newx$body.mass..kg., col = "black", lty=2, lwd=1,
         type="a",scale=list(x=list(log=T)))


F2d <- update(doubleYScale(f3, f4, use.style = T,
                           auto.key=list(text=c("RSF","DF"),lines=T, points=T,
                                         columns=2)),page = pgfun("(d)"),
              par.settings = list(layout.widths = list(left.padding = 1,
                                                       key.ylab.padding = 0,
                                                       ylab.axis.padding = 1,
                                                       axis.key.padding = -0.5,
                                                       right.padding = 1.5)))


width <- 17.8*1.25
height <- 16*1.25

tiff(filename = "Figure2.tif", 
     width = width, height = height, unit="cm", compression = "lzw", bg = "white", res = 300, restoreConsole = TRUE)

grid.arrange(F2a,F2b,F2c,F2d,ncol=2,nrow=2)
dev.off()




#################################################################
## Figure 3: 4 panel box-whiskter plot for the 4 measurements
#################################################################

pgfun <- function(mark) function(n) grid.text(label = mark, gp = gpar(fontface=2),check.overlap = T,
                                              x = unit(0.03, "npc"), y = unit(0.97, "npc")) 

cexy <- 0.85
cexx <- 0.85
tickx <- 0.7
ticky <- 0.7
tck <- 0.5

cex_dot <- 0.4
parbw <-
  list(layout.widths = list(ylab.axis.padding = 0),box.rectangle=list(col="black"),
       axis.line = list(col = 0),
       box.umbrella=list(col="black"),plot.symbol = list(pch=".",col = 0), 
       layout.heights =list(main.key.padding = -2))

panelbw <- function(...) {
  lims <- current.panel.limits() 
  panel.abline(h=lims$ylim[1],v=lims$xlim[1])
  panel.xyplot(...,jitter.x  = TRUE, pch=1,cex=cex_dot, amount=0.15, col="black")
  panel.bwplot(...,pch="|",col="black",box.width=0.3)
}

f1 <- bwplot(velocity..m.s. ~ clade.symm.asymm, data=whole,
             page = pgfun("(a)"),
             ylab=list(cex=cexy, label=expression(paste(Velocity," (", u,")","(",ms^{-1},")"))), 
             ylim=c(0.13,5),
  par.settings = parbw,
       scales=list(col=1,tck=c(tck,0),y=list(cex=ticky,log=T, at=c(0.15,0.5,1,2,3,4)),
                   x=list(cex=tickx, label=c("alli\nsymm","crocs\nasymm", "crocs\nsymm"))),
              panel=function(...){
         lims <- current.panel.limits() 
         panel.abline(h=lims$ylim[1],v=lims$xlim[1])
         panel.xyplot(...,jitter.x  = TRUE, pch=1,cex=cex_dot, amount=0.15, col="black")
         panel.bwplot(...,pch="|",col="black")
       })


f2 <- bwplot(Froude.0.5 ~ clade.symm.asymm, data=whole,
             page = pgfun("(b)"),
             ylab=list(cex=cexy, label=expression(paste(Froude^{ 0.5}, "( ",widehat("u"), " )"))), 
             ylim=c(0.08,4),
             par.settings = parbw,
             scales=list(col=1,tck=c(tck,0),y=list(cex=ticky,log=T, at=c(0.1,0.5,1,2,3)),
                         x=list(cex=tickx, label=c("alli\nsymm","crocs\nasymm", "crocs\nsymm"))),
             panel=function(...){
               lims <- current.panel.limits() 
               panel.abline(h=lims$ylim[1],v=lims$xlim[1])
               panel.xyplot(...,jitter.x  = TRUE, pch=1,cex=cex_dot, amount=0.15, col="black")
               panel.bwplot(...,pch="|",col="black")
             })



f3 <- bwplot(rel.stride.freq ~ clade.symm.asymm, data=whole,
             page = pgfun("(c)"),
             ylab=list(cex=cexy, label="Relative stride frequency (RSF)"), 
             ylim=c(-0.02,0.82),
             par.settings = parbw,
             scales=list(col=1,tck=c(tck,0),y=list(cex=ticky,at=c(0,0.2,0.4,0.6,0.8)),
                         x=list(cex=tickx, label=c("alli\nsymm","crocs\nasymm", "crocs\nsymm"))),
             panel=function(...){
               lims <- current.panel.limits() 
               panel.abline(h=lims$ylim[1],v=lims$xlim[1])
               panel.xyplot(...,jitter.x  = TRUE, pch=1,cex=cex_dot, amount=0.15, col="black")
               panel.bwplot(...,pch="|",col="black")
             })

f4 <- bwplot(duty.factor ~ clade.symm.asymm, data=whole,
             page = pgfun("(d)"),
             ylab=list(cex=cexy, label="Duty factor (DF)"), 
             ylim=c(0.18,0.82),
             par.settings = parbw,
             scales=list(col=1,tck=c(tck,0),y=list(cex=ticky,at=c(0.2,0.4,0.6,0.8)),
                         x=list(cex=tickx, label=c("alli\nsymm","crocs\nasymm", "crocs\nsymm"))),
             panel=function(...){
               lims <- current.panel.limits() 
               panel.abline(h=lims$ylim[1],v=lims$xlim[1])
               panel.xyplot(...,jitter.x  = TRUE, pch=1,cex=cex_dot, amount=0.15, col="black")
               panel.bwplot(...,pch="|",col="black")
             })

width <- 17.8
height <- 16

tiff(filename = "Figure3.tif", 
     width = width, height = height, unit="cm", compression = "lzw", bg = "white", res = 300, restoreConsole = TRUE)

grid.arrange(f1,f2,f3,f4,ncol=2,nrow=2, clip=F)
dev.off()


##############################################################
## Figure 4: 4 panel plot, use only half width for each panel
##############################################################
pgfun <- function(mark) function(n) grid.text(label = mark, gp = gpar(fontface=2),check.overlap = T,
                                              x = unit(0.06, "npc"), y = unit(0.97, "npc")) 

cexy <- 0.85
cexx <- 0.85
tickx <- 0.7
ticky <- 0.7
tck <- 0.5

cex_dot <- 0.4
parbw <-
  list(layout.widths = list(ylab.axis.padding = 0,
                            left.padding = 1,
                            key.ylab.padding = 0,
                            axis.key.padding = 0,
                            right.padding = 0),
                            box.rectangle=list(col="black"),
       axis.line = list(col = 0),
       box.umbrella=list(col="black"),plot.symbol = list(pch=".",col = 0), 
       layout.heights =list(main.key.padding = -2))


panelbw <- function(...) {
  lims <- current.panel.limits() 
  panel.abline(h=lims$ylim[1],v=lims$xlim[1])
  panel.xyplot(...,jitter.x  = TRUE, pch=1,cex=cex_dot, amount=0.15, col="black")
  panel.bwplot(...,pch="|",col="black",box.width=0.5)
}

f1 <- bwplot(velocity..m.s. ~ clade.symm.asymm, data=dmax,subset=clade.symm.asymm!="crocs-symm",
             page = pgfun("(a)"),
             ylab=list(cex=cexy, label=expression(paste(Velocity," (", u,")","(",ms^{-1},")"))), 
             ylim=c(1.3,4.2),
             par.settings = parbw,
             scales=list(col=1,tck=c(tck,0),y=list(cex=ticky,log=T, at=c(1.5,2,3,4)),
                         x=list(cex=tickx, labels=c("alli\nsymm","crocs\nasymm"))),
             panel=function(...){
               lims <- current.panel.limits() 
               panel.abline(h=lims$ylim[1],v=lims$xlim[1])
               panel.xyplot(...,jitter.x  = TRUE, pch=1,cex=cex_dot, amount=0.15, col="black")
               panel.bwplot(...,pch="|",col="black",box.width=0.3)
             })



f2 <- bwplot(Froude.0.5 ~ clade.symm.asymm, data=dmax,page = pgfun("(b)"),
             subset=clade.symm.asymm!="crocs-symm",
             ylab=list(cex=cexy, label=expression(paste(Froude^{ 0.5}, "( ",widehat("u"), " )"))), 
             ylim=c(0.85,3.6),
             par.settings = parbw,
             scales=list(col=1,tck=c(tck,0),y=list(cex=ticky,log=T, at=c(1,1.5,2,3,3.5)),
                         x=list(cex=tickx, labels=c("alli\nsymm","crocs\nasymm"))),
             panel=function(...){
               lims <- current.panel.limits() 
               panel.abline(h=lims$ylim[1],v=lims$xlim[1])
               panel.xyplot(...,jitter.x  = TRUE, pch=1,cex=cex_dot, amount=0.15, col="black")
               panel.bwplot(...,pch="|",col="black",box.width=0.3)
             })



f3 <- bwplot(rel.stride.freq ~ clade.symm.asymm, data=dmax,page = pgfun("(c)"),
             subset=clade.symm.asymm!="crocs-symm",
             ylab=list(cex=cexy, label="Relative stride frequency (RSF)"), 
             ylim=c(0.28,0.62),
             par.settings = parbw,
             scales=list(col=1,tck=c(tck,0),y=list(cex=ticky,at=c(0.3,0.4,0.5,0.6)),
                         x=list(cex=tickx, labels=c("alli\nsymm","crocs\nasymm"))),
             panel=function(...){
               lims <- current.panel.limits() 
               panel.abline(h=lims$ylim[1],v=lims$xlim[1])
               panel.xyplot(...,jitter.x  = TRUE, pch=1,cex=cex_dot, amount=0.15, col="black")
               panel.bwplot(...,pch="|",col="black",box.width=0.3)
             })

f4 <- bwplot(duty.factor ~ clade.symm.asymm, data=dmax,page = pgfun("(d)"),
             subset=clade.symm.asymm!="crocs-symm",
             ylab=list(cex=cexy, label="Duty factor (DF)"), 
             ylim=c(0.23,0.62),
             par.settings = parbw,
             scales=list(col=1,tck=c(tck,0),y=list(cex=ticky,at=c(0.3,0.4,0.5,0.6)),
                         x=list(cex=tickx, label=c("alli\nsymm","crocs\nasymm"))),
               panel=function(...){
               lims <- current.panel.limits() 
               panel.abline(h=lims$ylim[1],v=lims$xlim[1])
               panel.xyplot(...,jitter.x  = TRUE, pch=1,cex=cex_dot, amount=0.15, col="black")
               panel.bwplot(...,pch="|",col="black",box.width=0.3)
             })


width <- 17.8
height <- 8

tiff(filename = "Figure4.tif", 
     width = width, height = height, unit="cm", compression = "lzw", bg = "white", res = 300, restoreConsole = TRUE)

grid.arrange(f1,f2,f3,f4,ncol=4,nrow=1,clip=F)
dev.off()
